@@ -9,7 +9,10 @@ pub(super) mod bybit;
 pub(super) mod deribit;
 pub(super) mod dydx;
 pub(super) mod ftx;
+pub(super) mod gate;
 pub(super) mod huobi;
 pub(super) mod kraken;
 pub(super) mod kucoin;
+pub(super) mod mxc;
+pub(super) mod okex;
 pub(super) mod zbg;
