@@ -76,8 +76,9 @@ pub fn normalize_pair(symbol: &str, exchange: &str) -> Option<String> {
 
 /// Infer out market type from the symbol.
 ///
-/// The `is_spot` parameter is not needed in most cases, but sometimes a symbol
-/// exists in both spot and contract markets, for example:
+/// The `is_spot` parameter is not needed in most cases, but at some exchanges
+///  (including binance, gate and mxc) a symbol might exist in both spot and
+/// contract markets, for example:
 /// * At binance `BTCUSDT` exists in both spot and linear_swap markets
 /// * At gate `BTC_USDT` exists in both spot and linear_swap markets,
 /// `BTC_USD` exists in both spot and inverse_swap markets
@@ -98,7 +99,7 @@ pub fn get_market_type(symbol: &str, exchange: &str, is_spot: Option<bool>) -> M
         "huobi" => exchanges::huobi::get_market_type(symbol),
         "kraken" => MarketType::Spot,
         "kucoin" => exchanges::kucoin::get_market_type(symbol),
-        "mxc" => exchanges::mxc::get_market_type(symbol),
+        "mxc" => exchanges::mxc::get_market_type(symbol, is_spot),
         "okex" => exchanges::okex::get_market_type(symbol),
         "zbg" => exchanges::zbg::get_market_type(symbol),
         _ => MarketType::Unknown,
